pub struct Message {
pub id: String,
pub role: MessageRole,
pub parts: Vec<MessagePart>,
pub metadata: Option<Value>,
}Expand description
A message exchanged between agents during a task.
Fields
id: StringUnique identifier for this message.
role: MessageRoleRole of the sender.
parts: Vec<MessagePart>Content parts of the message.
metadata: Option<Value>Optional metadata.
Implementations
Sourceimpl Message
impl Message
Sourcepub fn user(parts: Vec<MessagePart>) -> Self
pub fn user(parts: Vec<MessagePart>) -> Self
Create a message from the user (client agent).
Sourcepub fn agent(parts: Vec<MessagePart>) -> Self
pub fn agent(parts: Vec<MessagePart>) -> Self
Create a message from the remote agent.
Sourcepub fn user_text(text: impl Into<String>) -> Self
pub fn user_text(text: impl Into<String>) -> Self
Convenience: create a user message with a single text part.
Sourcepub fn agent_text(text: impl Into<String>) -> Self
pub fn agent_text(text: impl Into<String>) -> Self
Convenience: create an agent message with a single text part.
Sourcepub fn text_content(&self) -> String
pub fn text_content(&self) -> String
Extract all text content from this message.